@@ -1,5 +1,4 @@
 import argparse
-import logging
 import sys
 
 from .command import Command
@@ -13,7 +12,6 @@ class HelpAction(argparse.Action):
     instance, passed in as the "default" value for the action.
     """
     def __call__(self, parser, namespace, values, option_string=None):
-        log = logging.getLogger(__name__)
         app = self.default
         parser.print_help(app.stdout)
         app.stdout.write('\nCommands:\n')
